==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/analysis/v1alpha1/AnalysisMessageBaseFluent.java <==
package io.fabric8.istio.api.analysis.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AnalysisMessageBaseFluent<A extends AnalysisMessageBaseFluent<A>> extends BaseFluent<A>{
  public AnalysisMessageBaseFluent() {
  }
  public AnalysisMessageBaseFluent(AnalysisMessageBase instance) {
    instance = (instance != null ? instance : new AnalysisMessageBase());

    if (instance != null) {
      this.withDocumentationUrl(instance.getDocumentationUrl());
      this.withLevel(instance.getLevel());
      this.withType(instance.getType());
      this.withDocumentationUrl(instance.getDocumentationUrl());
      this.withLevel(instance.getLevel());
      this.withType(instance.getType());
    }
  }
  private String documentationUrl;
  private AnalysisMessageBaseLevel level;
  private AnalysisMessageBaseTypeBuilder type;
  public String getDocumentationUrl() {
    return this.documentationUrl;
  }
  public A withDocumentationUrl(String documentationUrl) {
    this.documentationUrl=documentationUrl; return (A) this;
  }
  public boolean hasDocumentationUrl() {
    return this.documentationUrl != null;
  }
  public AnalysisMessageBaseLevel getLevel() {
    return this.level;
  }
  public A withLevel(AnalysisMessageBaseLevel level) {
    this.level=level; return (A) this;
  }
  public boolean hasLevel() {
    return this.level != null;
  }
  public AnalysisMessageBaseType buildType() {
    return this.type!=null ?this.type.build():null;
  }
  public A withType(AnalysisMessageBaseType type) {
    _visitables.get("type").remove(this.type);
    if (type!=null){ this.type= new AnalysisMessageBaseTypeBuilder(type); _visitables.get("type").add(this.type);} else { this.type = null; _visitables.get("type").remove(this.type); } return (A) this;
  }
  public boolean hasType() {
    return this.type != null;
  }
  public A withNewType(String code,String name) {
    return (A)withType(new AnalysisMessageBaseType(code, name));
  }
  public TypeNested<A> withNewType() {
    return new TypeNested(null);
  }
  public TypeNested<A> withNewTypeLike(AnalysisMessageBaseType item) {
    return new TypeNested(item);
  }
  public TypeNested<A> editType() {
    return withNewTypeLike(java.util.Optional.ofNullable(buildType()).orElse(null));
  }
  public TypeNested<A> editOrNewType() {
    return withNewTypeLike(java.util.Optional.ofNullable(buildType()).orElse(new AnalysisMessageBaseTypeBuilder().build()));
  }
  public TypeNested<A> editOrNewTypeLike(AnalysisMessageBaseType item) {
    return withNewTypeLike(java.util.Optional.ofNullable(buildType()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AnalysisMessageBaseFluent that = (AnalysisMessageBaseFluent) o;
    if (!java.util.Objects.equals(documentationUrl, that.documentationUrl)) return false;

    if (!java.util.Objects.equals(level, that.level)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(documentationUrl,  level,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (documentationUrl != null) { sb.append("documentationUrl:"); sb.append(documentationUrl + ","); }
    if (level != null) { sb.append("level:"); sb.append(level + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  public class TypeNested<N> extends AnalysisMessageBaseTypeFluent<TypeNested<N>> implements Nested<N>{
    TypeNested(AnalysisMessageBaseType item) {
      this.builder = new AnalysisMessageBaseTypeBuilder(this, item);
    }
    AnalysisMessageBaseTypeBuilder builder;
    public N and() {
      return (N) AnalysisMessageBaseFluent.this.withType(builder.build());
    }
    public N endType() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/analysis/v1alpha1/AnalysisMessageBaseFluent.java <==
package io.fabric8.istio.api.analysis.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AnalysisMessageBaseFluent<A extends AnalysisMessageBaseFluent<A>> extends BaseFluent<A>{
  public AnalysisMessageBaseFluent() {
  }
  
  public AnalysisMessageBaseFluent(AnalysisMessageBase instance) {
    this.copyInstance(instance);
  }
  private String documentationUrl;
  private AnalysisMessageBaseLevel level;
  private AnalysisMessageBaseTypeBuilder type;
  
  protected void copyInstance(AnalysisMessageBase instance) {
    instance = (instance != null ? instance : new AnalysisMessageBase());
  
    if (instance != null) {
        this.withDocumentationUrl(instance.getDocumentationUrl());
        this.withLevel(instance.getLevel());
        this.withType(instance.getType());
        this.withDocumentationUrl(instance.getDocumentationUrl());
        this.withLevel(instance.getLevel());
        this.withType(instance.getType());
      }
  }
  
  public String getDocumentationUrl() {
    return this.documentationUrl;
  }
  
  public A withDocumentationUrl(String documentationUrl) {
    this.documentationUrl=documentationUrl; return (A) this;
  }
  
  public boolean hasDocumentationUrl() {
    return this.documentationUrl != null;
  }
  
  public AnalysisMessageBaseLevel getLevel() {
    return this.level;
  }
  
  public A withLevel(AnalysisMessageBaseLevel level) {
    this.level=level; return (A) this;
  }
  
  public boolean hasLevel() {
    return this.level != null;
  }
  
  public AnalysisMessageBaseType buildType() {
    return this.type!=null ?this.type.build():null;
  }
  
  public A withType(AnalysisMessageBaseType type) {
    _visitables.get("type").remove(this.type);
    if (type!=null){ this.type= new AnalysisMessageBaseTypeBuilder(type); _visitables.get("type").add(this.type);} else { this.type = null; _visitables.get("type").remove(this.type); } return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A withNewType(String code,String name) {
    return (A)withType(new AnalysisMessageBaseType(code, name));
  }
  
  public TypeNested<A> withNewType() {
    return new TypeNested(null);
  }
  
  public TypeNested<A> withNewTypeLike(AnalysisMessageBaseType item) {
    return new TypeNested(item);
  }
  
  public TypeNested<A> editType() {
    return withNewTypeLike(java.util.Optional.ofNullable(buildType()).orElse(null));
  }
  
  public TypeNested<A> editOrNewType() {
    return withNewTypeLike(java.util.Optional.ofNullable(buildType()).orElse(new AnalysisMessageBaseTypeBuilder().build()));
  }
  
  public TypeNested<A> editOrNewTypeLike(AnalysisMessageBaseType item) {
    return withNewTypeLike(java.util.Optional.ofNullable(buildType()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AnalysisMessageBaseFluent that = (AnalysisMessageBaseFluent) o;
    if (!java.util.Objects.equals(documentationUrl, that.documentationUrl)) return false;
  
    if (!java.util.Objects.equals(level, that.level)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(documentationUrl,  level,  type,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (documentationUrl != null) { sb.append("documentationUrl:"); sb.append(documentationUrl + ","); }
    if (level != null) { sb.append("level:"); sb.append(level + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  public class TypeNested<N> extends AnalysisMessageBaseTypeFluent<TypeNested<N>> implements Nested<N>{
    TypeNested(AnalysisMessageBaseType item) {
      this.builder = new AnalysisMessageBaseTypeBuilder(this, item);
    }
    AnalysisMessageBaseTypeBuilder builder;
    
    public N and() {
      return (N) AnalysisMessageBaseFluent.this.withType(builder.build());
    }
    
    public N endType() {
      return and();
    }
    
  
  }

}
